﻿using Kivii.DataAnnotations;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace Kivii.Third.Scjgj.Entities
{
    [Api(Description = "受检单位信息")]
    [Alias(Configs.TableNameCary)]
    public class Cary : Entity, IEntityIgnoreCreateTable, IEntityInAssemblyDb
    {
        #region IEntity Ignore
        [PrimaryKey]
        [Ignore]
        [IgnoreUpdate]
        [Alias("UUID")]
        public new Guid Kvid { get; set; }

        [Ignore]
        [Alias("CREATEDATE")]
        public new DateTime CreateTime { get; set; }


        /// <summary>
        ///// 结果通知日期
        /// </summary>
        [Ignore]
        [Alias("NOTICE_TIME")]
        public new DateTime UpdateTime { get; set; }

        [Ignore]
        /// <summary>
        ///// 任务状态(1.未下达 2.已下达 3.已领取 4.已完成 0.已撤回 5.已上传)
        /// </summary>
        [Alias("PLAN_STATE")]
        public new int Status { get; set; }
        #endregion

        /// <summary>
        /// 自增编号
        /// </summary>
        [PrimaryKey]
        public int ID { get; set; }

        /// <summary>
        /// 受检单位编码
        /// </summary>
        [StringLength(30)]
        public string CARY_CODE { get; set; }

        /// <summary>
        /// 受检单位名称
        /// </summary>
        [StringLength(200)]
        public string CARY_NAME { get; set; }

        /// <summary>
        /// 受检单位法人代表
        /// </summary>
        [StringLength(200)]
        public string CARY_PRESENT { get; set; }

        /// <summary>
        /// 受检单位通讯地址
        /// </summary>
        [StringLength(2000)]
        public string CARY_ADDR { get; set; }

        /// <summary>
        /// 受检单位邮编
        /// </summary>
        [StringLength(10)]
        public string CARY_ZIP_CODE { get; set; }

        /// <summary>
        /// 受检单位联系人
        /// </summary>
        [StringLength(200)]
        public string CARY_LINKMAN { get; set; }

        /// <summary>
        /// 受检单位联系电话
        /// </summary>
        [StringLength(200)]
        public string CARY_TEL { get; set; }

        /// <summary>
        /// 受检单位管理生产企业
        /// </summary>
        public int? CARY_RELATED_PRO_ID { get; set; }

        /// <summary>
        /// 受检单位所属地
        /// </summary>
        [StringLength(200)]
        public string CARY_OWNERSHIP { get; set; }

        /// <summary>
        /// 统一社会信用代码（营业执照注册号）
        /// </summary>
        [StringLength(200)]
        public string UNIFIED_SOCIAL_CREDIT_CODE { get; set; }

        /// <summary>
        /// 受检单位所属地（省编码）
        /// </summary>
        [StringLength(200)]
        public string CARY_PROVINCE { get; set; }

        /// <summary>
        /// 受检单位所属地（市编码）
        /// </summary>
        [StringLength(200)]
        public string CARY_CITY { get; set; }

        /// <summary>
        /// 受检单位所属地（区/县编码）
        /// </summary>
        [StringLength(200)]
        public string CARY_COUNTY { get; set; }

        /// <summary>
        /// 经营者所在地（1：城区，2：城郊结合部，3：乡镇）
        /// </summary>
        [StringLength(1)]
        public string OPERATOR_LOCATION { get; set; }

    }

    [Api(Description = "生产单位信息")]
    [Alias(Configs.TableNameProduceUnit)]
    public class ProduceUnit : Entity, IEntityIgnoreCreateTable, IEntityInAssemblyDb
    {
        #region IEntity Ignore
        [Ignore]
        [PrimaryKey]
        [IgnoreUpdate]
        [Alias("UUID")]
        public new Guid Kvid { get; set; }

        [Ignore]
        [Alias("CREATEDATE")]
        public new DateTime CreateTime { get; set; }

        /// <summary>
        ///// 结果通知日期
        /// </summary>
        [Ignore]
        [Alias("NOTICE_TIME")]
        public new DateTime UpdateTime { get; set; }

        [Ignore]
        /// <summary>
        ///// 任务状态(1.未下达 2.已下达 3.已领取 4.已完成 0.已撤回 5.已上传)
        /// </summary>
        [Alias("PLAN_STATE")]
        public new int Status { get; set; }
        #endregion

        /// <summary>
        /// 自增编号
        /// </summary>
        [PrimaryKey]
        public int ID { get; set; }

        /// <summary>
        /// 生产单位编码
        /// </summary>
        [StringLength(30)]
        public string PRO_CODE { get; set; }

        /// <summary>
        /// 生产单位名称
        /// </summary>
        [StringLength(200)]
        public string PRO_NAME { get; set; }

        /// <summary>
        /// 生产单位所属地
        /// </summary>
        [StringLength(200)]
        public string PRO_OWNERSHIP { get; set; }

        /// <summary>
        /// 生产单位地址
        /// </summary>
        [StringLength(2000)]
        public string PRO_ADDR { get; set; }

        /// <summary>
        /// 生产单位邮编
        /// </summary>
        [StringLength(10)]
        public string PRO_ZIP_CODE { get; set; }

        /// <summary>
        /// 生产单位法人代表
        /// </summary>
        [StringLength(200)]
        public string PRO_PRESENT { get; set; }

        /// <summary>
        /// 生产单位联系人
        /// </summary>
        [StringLength(200)]
        public string PRO_LINKMAN { get; set; }

        /// <summary>
        /// 生产单位联系电话
        /// </summary>
        [StringLength(200)]
        public string PRO_TEL { get; set; }

        /// <summary>
        /// 生产单位手机
        /// </summary>
        [StringLength(50)]
        public string PRO_PHONE { get; set; }

        /// <summary>
        /// 生产单位营业执照(统一社会信用代码)
        /// </summary>
        [StringLength(500)]
        public string PRO_BUS_LICENCE { get; set; }

        /// <summary>
        /// 生产单位机构代码
        /// </summary>
        [StringLength(200)]
        public string PRO_ORGAN_CODE { get; set; }

        /// <summary>
        /// 生产单位企业规模
        /// 1：大， 2：中， 3：小
        /// </summary>
        [StringLength(50)]
        public string PRO_SACLE { get; set; }

        /// <summary>
        /// 经济类型内资
        /// 1：国有，2：集体，3：股份合作，4：联营，5：有限责任公司，6：股份有限公司，7：私营，8：其他企业
        /// </summary>
        public char? ECO_INSIDE { get; set; }

        /// <summary>
        /// 生产单位质量认证体系
        /// 1：工业产品生产许可证，3：CCC，4：其他，5：强制性产品认证，6：特种设备制造许可
        /// </summary>
        public char? PRO_QUALITY_PASS { get; set; }

        /// <summary>
        /// 经济类型港澳台
        /// 1：合资经营，2：合作经营，3：港澳台独资经营，4：澳台投资股份有限公司
        /// </summary>
        public char? ECO_HMT { get; set; }

        /// <summary>
        /// 经济类型外资
        /// 1：中外合资，2：中外合作，3：外资企业，4：外商投资股份有限公司，5：有限责任公司
        /// </summary>
        public char? ECO_OUTSIDE { get; set; }

        /// <summary>
        /// 经济类型个体
        /// 1：个体户，2：个人合作，3：个人独资
        /// </summary>
        public char? ECO_SINGLE { get; set; }

        /// <summary>
        /// 生产单位证书编码
        /// </summary>
        [StringLength(500)]
        public string PRO_CERT_CODE { get; set; }

        /// <summary>
        /// 生产单位企业规模类型
        /// </summary>
        public char? PRO_SACLE_TYPE { get; set; }

        /// <summary>
        /// 组织机构代码
        /// </summary>
        [StringLength(100)]
        public string PRO_ORG_CODE { get; set; }

        /// <summary>
        /// 机构名称
        /// </summary>
        [StringLength(200)]
        public string PRO_ORG_NAME { get; set; }

        /// <summary>
        /// 企业信用代码
        /// </summary>
        [StringLength(100)]
        public string PRO_CREDIT_CODE { get; set; }

        /// <summary>
        /// 是否为规模以上企业
        /// </summary>
        [StringLength(10)]
        public string PRO_IS_SCALE { get; set; }

        /// <summary>
        /// 品牌建设
        /// 1：江苏名称，2：江苏质量奖，3：中国质量奖，4：著名商标，5：知名商标，6：无
        /// </summary>
        public char? PRO_BRAND_BUILDING { get; set; }

        /// <summary>
        /// 产品分类代码
        /// </summary>
        [StringLength(100)]
        public string PRO_CLASS_CODE { get; set; }

        /// <summary>
        /// 生产单位所属地（省编码）
        /// </summary>
        [StringLength(200)]
        public string PRO_PROVINCE { get; set; }

        /// <summary>
        /// 生产单位所属地（市编码）
        /// </summary>
        [StringLength(200)]
        public string PRO_CITY { get; set; }

        /// <summary>
        /// 生产单位所属地（区/县编码）
        /// </summary>
        [StringLength(200)]
        public string PRO_COUNTY { get; set; }

        /// <summary>
        /// 产品分类名称
        /// </summary>
        [StringLength(100)]
        public string PRO_CPMC_NAME { get; set; }

    }

    [Api(Description = "抽样机构信息")]
    [Alias(Configs.TableNameExecUint)]
    public class ExecUint : Entity, IEntityIgnoreCreateTable, IEntityInAssemblyDb
    {
        #region IEntity Ignore
        [Ignore]
        [PrimaryKey]
        [IgnoreUpdate]
        [Alias("UUID")]
        public new Guid Kvid { get; set; }

        [Ignore]
        [Alias("CREATEDATE")]
        public new DateTime CreateTime { get; set; }

        /// <summary>
        ///// 结果通知日期
        /// </summary>
        [Ignore]
        [Alias("NOTICE_TIME")]
        public new DateTime UpdateTime { get; set; }

        [Ignore]
        /// <summary>
        ///// 任务状态(1.未下达 2.已下达 3.已领取 4.已完成 0.已撤回 5.已上传)
        /// </summary>
        [Alias("PLAN_STATE")]
        public new int Status { get; set; }
        #endregion

        /// <summary>
        /// 自增编号
        /// </summary>
        [PrimaryKey]
        public int ID { get; set; }

        /// <summary>
        /// 抽样单位编码
        /// </summary>
        [StringLength(30)]
        public string EXEC_CODE { get; set; }

        /// <summary>
        /// 抽样单位名称
        /// </summary>
        [StringLength(200)]
        public string EXEC_NAME { get; set; }

        /// <summary>
        /// 抽样单位地址
        /// </summary>
        [StringLength(2000)]
        public string EXEC_ADDR { get; set; }

        /// <summary>
        /// 抽样单位邮编
        /// </summary>
        [StringLength(10)]
        public string EXEC_ZIP_CODE { get; set; }

        /// <summary>
        /// 抽样单位联系人
        /// </summary>
        [StringLength(200)]
        public string EXEC_LINKMAN { get; set; }

        /// <summary>
        /// 抽样单位联系电话
        /// </summary>
        [StringLength(200)]
        public string EXEC_TEL { get; set; }

        /// <summary>
        /// 抽样单位传真
        /// </summary>
        [StringLength(200)]
        public string EXEC_FAX { get; set; }

    }

    [Api(Description = "电商单位信息")]
    [Alias(Configs.TableNameEcPlatform)]
    public class EcPlatform : Entity, IEntityIgnoreCreateTable, IEntityInAssemblyDb
    {
        #region IEntity Ignore
        [Ignore]
        [PrimaryKey]
        [IgnoreUpdate]
        [Alias("UUID")]
        public new Guid Kvid { get; set; }

        [Ignore]
        [Alias("CREATEDATE")]
        public new DateTime CreateTime { get; set; }

        /// <summary>
        ///// 结果通知日期
        /// </summary>
        [Ignore]
        [Alias("NOTICE_TIME")]
        public new DateTime UpdateTime { get; set; }

        [Ignore]
        /// <summary>
        ///// 任务状态(1.未下达 2.已下达 3.已领取 4.已完成 0.已撤回 5.已上传)
        /// </summary>
        [Alias("PLAN_STATE")]
        public new int Status { get; set; }
        #endregion

        /// <summary>
        /// 自增id
        /// </summary>
        [PrimaryKey]
        public int EC_ID { get; set; }

        /// <summary>
        /// 网店名称
        /// </summary>
        [StringLength(200)]
        public string ONLINE_STORE_NAME { get; set; }

        /// <summary>
        /// 网店通讯地址
        /// </summary>
        [StringLength(2000)]
        public string ONLINE_STORE_ADDR { get; set; }

        /// <summary>
        /// 网店营业注册码
        /// </summary>
        [StringLength(200)]
        public string ONLINE_STORE_POLL_CODE { get; set; }

        /// <summary>
        /// 网店联系方式
        /// </summary>
        [StringLength(200)]
        public string ONLINE_STORE_CONTACT { get; set; }

        /// <summary>
        /// 网店网址链接
        /// </summary>
        [StringLength(500)]
        public string ONLINE_STORE_LINK { get; set; }

        /// <summary>
        /// 电商平台名称
        /// </summary>
        [StringLength(200)]
        public string EC_PLATFORM_NAME { get; set; }

        /// <summary>
        /// 电商平台链接
        /// </summary>
        [StringLength(200)]
        public string EC_PLATFORM_LINK { get; set; }

        /// <summary>
        /// 网店订单编号
        /// </summary>
        [StringLength(200)]
        public string ONLINE_ORDER_CODE { get; set; }

        /// <summary>
        /// 商品网址链接（含商品唯一识别号）
        /// </summary>
        [StringLength(500)]
        public string LINKS_WEB_SITES { get; set; }

        /// <summary>
        /// 网店所属地
        /// </summary>
        [StringLength(200)]
        public string ONLINE_OWNERSHIP { get; set; }

        /// <summary>
        /// 平台所属地
        /// </summary>
        [StringLength(200)]
        public string EC_PLATFORM_OWNERSHIP { get; set; }

        /// <summary>
        /// 平台所属地（省编码）
        /// </summary>
        [StringLength(200)]
        public string EC_PLATFORM_PROVINCE { get; set; }

        /// <summary>
        /// 平台所属地（市编码）
        /// </summary>
        [StringLength(200)]
        public string EC_PLATFORM_CITY { get; set; }

        /// <summary>
        /// 平台所属地（区/县编码）
        /// </summary>
        [StringLength(200)]
        public string EC_PLATFORM_COUNTY { get; set; }

        /// <summary>
        /// 网店所属地（省编码）
        /// </summary>
        [StringLength(200)]
        public string ONLINE_PROVINCE { get; set; }

        /// <summary>
        /// 网店所属地（市编码）
        /// </summary>
        [StringLength(200)]
        public string ONLINE_CITY { get; set; }

        /// <summary>
        /// 网店所属地（区/县编码）
        /// </summary>
        [StringLength(200)]
        public string ONLINE_COUNTY { get; set; }

        /// <summary>
        /// 电商类型,1:企业店铺，2:自然人店铺
        /// </summary>
        public char? ONLINE_TYPE { get; set; }

    }

    [Api(Description = "其他来源单位信息")]
    [Alias(Configs.TableNameOther)]
    public class Other : Entity, IEntityIgnoreCreateTable, IEntityInAssemblyDb
    {
        #region IEntity Ignore
        [Ignore]
        [PrimaryKey]
        [IgnoreUpdate]
        [Alias("UUID")]
        public new Guid Kvid { get; set; }

        [Ignore]
        [Alias("CREATEDATE")]
        public new DateTime CreateTime { get; set; }

        /// <summary>
        ///// 结果通知日期
        /// </summary>
        [Ignore]
        [Alias("NOTICE_TIME")]
        public new DateTime UpdateTime { get; set; }

        [Ignore]
        /// <summary>
        ///// 任务状态(1.未下达 2.已下达 3.已领取 4.已完成 0.已撤回 5.已上传)
        /// </summary>
        [Alias("PLAN_STATE")]
        public new int Status { get; set; }
        #endregion

        /// <summary>
        /// 自增编号
        /// </summary>
        [PrimaryKey]
        public int ID { get; set; }

        /// <summary>
        /// 其他来源单位编码
        /// </summary>
        [StringLength(30)]
        public string OTHER_CODE { get; set; }

        /// <summary>
        /// 其他来源单位名称
        /// </summary>
        [StringLength(200)]
        public string OTHER_NAME { get; set; }

        /// <summary>
        /// 其他来源单位法人代表
        /// </summary>
        [StringLength(200)]
        public string OTHER_PRESENT { get; set; }

        /// <summary>
        /// 其他来源单位通信地址
        /// </summary>
        [StringLength(2000)]
        public string OTHER_ADDR { get; set; }

        /// <summary>
        /// 其他来源单位邮编
        /// </summary>
        [StringLength(10)]
        public string OTHER_ZIP_CODE { get; set; }

        /// <summary>
        /// 其他来源单位联系人
        /// </summary>
        [StringLength(200)]
        public string OTHER_LINKMAN { get; set; }

        /// <summary>
        /// 其他来源单位联系电话
        /// </summary>
        [StringLength(20)]
        public string OTHER_TEL { get; set; }

        /// <summary>
        /// 统一社会信用代码（营业执照注册号）
        /// </summary>
        [StringLength(200)]
        public string OTHER_UNIFIED_SOCIAL_CREDIT { get; set; }

    }

    [Api(Description = "直播平台信息")]
    [Alias(Configs.TableNameLive)]
    public class Live : Entity, IEntityIgnoreCreateTable, IEntityInAssemblyDb
    {
        #region IEntity Ignore
        [Ignore]
        [PrimaryKey]
        [IgnoreUpdate]
        [Alias("UUID")]
        public new Guid Kvid { get; set; }

        [Ignore]
        [Alias("CREATEDATE")]
        public new DateTime CreateTime { get; set; }

        /// <summary>
        ///// 结果通知日期
        /// </summary>
        [Ignore]
        [Alias("NOTICE_TIME")]
        public new DateTime UpdateTime { get; set; }

        [Ignore]
        /// <summary>
        ///// 任务状态(1.未下达 2.已下达 3.已领取 4.已完成 0.已撤回 5.已上传)
        /// </summary>
        [Alias("PLAN_STATE")]
        public new int Status { get; set; }
        #endregion

        /// <summary>
        /// 直播平台ID
        /// </summary>
        [PrimaryKey]
        public int LIVE_ID { get; set; }

        /// <summary>
        /// 直播平台名称
        /// 1-淘宝, 2-苏宁易购, 3-天猫, 4-京东, 5-1号店, 6-唯品会, 7-亚马逊, 8-当当网, 9-国美在线, 10-3D打印在线,
        /// 11-三迪时空, 12-飞牛网, 13-其他, 14-阿里巴巴, 15-拼多多, 16-聚美优品, 17-孩子王, 18-邮储食堂, 19-小米有品,
        /// 20-1688, 21-抖音, 22-快手小店, 23-快手, 24-食行生鲜
        /// </summary>
        [StringLength(200)]
        public string LIVE_NAME { get; set; }

        /// <summary>
        /// 直播平台所属地
        /// </summary>
        [StringLength(200)]
        public string LIVE_OWNERSHIP { get; set; }

        /// <summary>
        /// 直播平台所属地(省编码)
        /// </summary>
        [StringLength(200)]
        public string LIVE_PROVINCE { get; set; }

        /// <summary>
        /// 直播平台所属地(市编码)
        /// </summary>
        [StringLength(200)]
        public string LIVE_CITY { get; set; }

        /// <summary>
        /// 直播平台所属地(区/县编码)
        /// </summary>
        [StringLength(200)]
        public string LIVE_COUNTY { get; set; }

        /// <summary>
        /// 直播间ID
        /// </summary>
        [StringLength(200)]
        public string LIVE_ROOM_CODE { get; set; }

        /// <summary>
        /// 直播间昵称
        /// </summary>
        [StringLength(200)]
        public string LIVE_ROOM_NAME { get; set; }

        /// <summary>
        /// 是否本平台直接销售
        /// </summary>
        public char? IF_SALES { get; set; }

    }

    [Api(Description = "抽样照片信息")]
    [Alias(Configs.TableNameBigData)]
    public class BigData : Entity, IEntityIgnoreCreateTable, IEntityInAssemblyDb
    {
        #region IEntity Ignore
        [PrimaryKey]
        [IgnoreUpdate]
        [Alias("UUID")]
        public new Guid Kvid { get; set; }

        [Alias("CREATEDATE")]
        public new DateTime CreateTime { get; set; }

        /// <summary>
        ///// 结果通知日期
        /// </summary>
        //[Ignore]
        [Alias("NOTICE_TIME")]
        public new DateTime UpdateTime { get; set; }

        //[Ignore]
        /// <summary>
        ///// 任务状态(1.未下达 2.已下达 3.已领取 4.已完成 0.已撤回 5.已上传)
        /// </summary>
        [Alias("PLAN_STATE")]
        public new int Status { get; set; }
        #endregion

        [PrimaryKey]
        public long DATA_ID { get; set; }

        public byte[] CONTENT { get; set; }

        [StringLength(100)]
        public string DATA_TYPE { get; set; }

        [StringLength(100)]
        public string FILE_NAME { get; set; }

        public DateTime? SAVE_TIME { get; set; }

        public int DATA_BYTES { get; set; }

        /// <summary>
        /// 关联PM_PLAN_SUB表的照片ID
        /// IMG_GROUP_ID,IMG_DELIVERY_GROUP_ID,IMG_101_GROUP_ID,IMG_102_GROUP_ID,IMG_103_GROUP_ID,IMG_104_GROUP_ID,IMG_105_GROUP_ID,IMG_106_GROUP_ID,IMG_107_GROUP_ID,IMG_108_GROUP_ID,IMG_109_GROUP_ID,IMG_110_GROUP_ID,IMG_111_GROUP_ID,IMG_DELIVERY_GROUP_ID,IMG_101_GROUP_ID,IMG_102_GROUP_ID,IMG_103_GROUP_ID,IMG_104_GROUP_ID,IMG_105_GROUP_ID,IMG_106_GROUP_ID,IMG_107_GROUP_ID,IMG_108_GROUP_ID,IMG_109_GROUP_ID,IMG_110_GROUP_ID,IMG_111_GROUP_ID
        /// </summary>
        public long? GROUP_ID { get; set; }

        /// <summary>
        /// 如果数据保存在文件系统，则记录保存的文件路径
        /// </summary>
        [StringLength(1000)]
        public string SAVE_FILE_PATH { get; set; }

        /// <summary>
        /// 关联数据ID
        /// </summary>
        public long? REF_DATA_ID { get; set; }

    }

    [Api(Description = "批次采集更新表")]
    [Alias(Configs.TableNamePlanUp)]
    public class PlanUp : Entity, IEntityIgnoreCreateTable, IEntityInAssemblyDb
    {
        #region IEntity Ignore
        [PrimaryKey]
        [IgnoreUpdate]
        [Alias("UUID")]
        public new Guid Kvid { get; set; }

        [Alias("CREATEDATE")]
        public new DateTime CreateTime { get; set; }

        /// <summary>
        ///// 结果通知日期
        /// </summary>
        //[Ignore]
        [Alias("NOTICE_TIME")]
        public new DateTime UpdateTime { get; set; }

        //[Ignore]
        /// <summary>
        ///// 任务状态(1.未下达 2.已下达 3.已领取 4.已完成 0.已撤回 5.已上传)
        /// </summary>
        [Alias("PLAN_STATE")]
        public new int Status { get; set; }
        #endregion

        /// <summary>
        /// 批次ID
        /// </summary>
        [PrimaryKey]
        public int ID { get; set; }

        /// <summary>
        /// 任务下载 0：未下载 1：已下载
        /// </summary>
        public char? RWXZ { get; set; }

        /// <summary>
        /// 任务编号
        /// </summary>
        [StringLength(30)]
        public string PLAN_CODE { get; set; }

    }

    [Api(Description = "任务来源对照表")]
    [Alias(Configs.TableNameTaskSource)]
    public class TaskSource : Entity, IEntityIgnoreCreateTable, IEntityInAssemblyDb
    {
        #region IEntity Ignore
        [PrimaryKey]
        [IgnoreUpdate]
        [Alias("UUID")]
        public new Guid Kvid { get; set; }

        [Alias("CREATEDATE")]
        public new DateTime CreateTime { get; set; }

        /// <summary>
        ///// 结果通知日期
        /// </summary>
        //[Ignore]
        [Alias("NOTICE_TIME")]
        public new DateTime UpdateTime { get; set; }

        //[Ignore]
        /// <summary>
        ///// 任务状态(1.未下达 2.已下达 3.已领取 4.已完成 0.已撤回 5.已上传)
        /// </summary>
        [Alias("PLAN_STATE")]
        public new int Status { get; set; }
        #endregion

        /// <summary>
        /// 行政区划 省局为3200 南京3201 无锡3202 其他市类推，各市行政区划前4位
        /// </summary>
        [StringLength(4)]
        public string AREA_NO { get; set; }

        /// <summary>
        /// 任务来源代码
        /// </summary>
        [StringLength(10)]
        public string TASK_SOURCE { get; set; }

        /// <summary>
        /// 任务来源名称
        /// </summary>
        [StringLength(100)]
        public string PM_CITY { get; set; }

    }
}
